{
    "$graph": [
        {
            "class": "CommandLineTool",
            "label": "replace problem characters from FASTA headers with dashes",
            "requirements": [
                {
                    "coresMax": 1,
                    "ramMin": 1024,
                    "class": "ResourceRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "streamable": true,
                    "format": "http://edamontology.org/format_1929",
                    "id": "#clean_fasta_headers.cwl/sequences"
                }
            ],
            "stdin": "$(inputs.sequences.path)",
            "baseCommand": [
                "tr",
                " /|<_;#",
                "-------"
            ],
            "stdout": "$(inputs.sequences.nameroot).cleaned.fasta",
            "id": "#clean_fasta_headers.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute",
            "outputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "id": "#clean_fasta_headers.cwl/sequences_with_cleaned_headers",
                    "outputBinding": {
                        "glob": "$(inputs.sequences.nameroot).cleaned.fasta"
                    }
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "coresMax": 1,
                    "ramMin": 100,
                    "class": "ResourceRequirement"
                }
            ],
            "hints": [
                {
                    "packages": [
                        {
                            "specs": [
                                "https://identifiers.org/rrid/RRID:SCR_007173"
                            ],
                            "version": [
                                "1.65",
                                "1.66",
                                "1.69"
                            ],
                            "package": "biopython"
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "streamable": true,
                    "format": "http://edamontology.org/format_1930",
                    "id": "#fastq_to_fasta.cwl/fastq"
                }
            ],
            "stdin": "$(inputs.fastq.path)",
            "baseCommand": [
                "python"
            ],
            "arguments": [
                {
                    "valueFrom": "import sys\nfrom Bio import SeqIO\nSeqIO.convert(sys.stdin, \"fastq\", sys.stdout, \"fasta\")\n",
                    "prefix": "-c"
                }
            ],
            "stdout": "$(inputs.fastq.basename).fasta",
            "outputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "id": "#fastq_to_fasta.cwl/fasta",
                    "outputBinding": {
                        "glob": "$(inputs.fastq.basename).fasta"
                    }
                }
            ],
            "id": "#fastq_to_fasta.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "coresMax": 1,
                    "ramMin": 100,
                    "class": "ResourceRequirement"
                }
            ],
            "hints": [
                {
                    "packages": [
                        {
                            "specs": null,
                            "package": "gunzip"
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1930",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#seqprep-merge.cwl/forward_unmerged_reads"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1930",
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#seqprep-merge.cwl/merged_reads"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1930",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#seqprep-merge.cwl/reverse_unmerged_reads"
                }
            ],
            "baseCommand": [
                "gunzip",
                "-c"
            ],
            "stdout": "merged_with_unmerged_reads",
            "outputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1930",
                    "id": "#seqprep-merge.cwl/merged_with_unmerged_reads",
                    "outputBinding": {
                        "glob": "merged_with_unmerged_reads"
                    }
                }
            ],
            "id": "#seqprep-merge.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "coresMax": 1,
                    "ramMin": 1024,
                    "class": "ResourceRequirement"
                }
            ],
            "hints": [
                {
                    "packages": [
                        {
                            "specs": [
                                "https://identifiers.org/rrid/RRID:SCR_013004"
                            ],
                            "version": [
                                "1.1"
                            ],
                            "package": "seqprep"
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1930",
                    "label": "first read input fastq",
                    "inputBinding": {
                        "prefix": "-f"
                    },
                    "id": "#seqprep.cwl/forward_reads"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1930",
                    "label": "second read input fastq",
                    "inputBinding": {
                        "prefix": "-r"
                    },
                    "id": "#seqprep.cwl/reverse_reads"
                }
            ],
            "baseCommand": "SeqPrep",
            "arguments": [
                "-1",
                "forward_unmerged.fastq.gz",
                "-2",
                "reverse_unmerged.fastq.gz",
                "-s",
                "merged.fastq.gz"
            ],
            "outputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1930",
                    "outputBinding": {
                        "glob": "forward_unmerged.fastq.gz"
                    },
                    "id": "#seqprep.cwl/forward_unmerged_reads"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1930",
                    "outputBinding": {
                        "glob": "merged.fastq.gz"
                    },
                    "id": "#seqprep.cwl/merged_reads"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1930",
                    "outputBinding": {
                        "glob": "reverse_unmerged.fastq.gz"
                    },
                    "id": "#seqprep.cwl/reverse_unmerged_reads"
                }
            ],
            "id": "#seqprep.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "hints": [
                {
                    "packages": [
                        {
                            "specs": [
                                "https://identifiers.org/rrid/RRID:SCR_011848"
                            ],
                            "version": [
                                "0.32",
                                "0.35",
                                "0.36"
                            ],
                            "package": "trimmomatic"
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "ramMin": 10240,
                    "coresMin": 8,
                    "class": "ResourceRequirement"
                },
                {
                    "types": [
                        {
                            "type": "enum",
                            "name": "#trimmomatic-end_mode.yaml/end_mode",
                            "symbols": [
                                "#trimmomatic-end_mode.yaml/end_mode/SE",
                                "#trimmomatic-end_mode.yaml/end_mode/PE"
                            ]
                        },
                        {
                            "type": "record",
                            "name": "#trimmomatic-sliding_window.yaml/slidingWindow",
                            "fields": [
                                {
                                    "name": "#trimmomatic-sliding_window.yaml/slidingWindow/windowSize",
                                    "type": "int"
                                },
                                {
                                    "name": "#trimmomatic-sliding_window.yaml/slidingWindow/requiredQuality",
                                    "type": "int"
                                }
                            ]
                        },
                        {
                            "type": "enum",
                            "name": "#trimmomatic-phred.yaml/phred",
                            "symbols": [
                                "#trimmomatic-phred.yaml/phred/64",
                                "#trimmomatic-phred.yaml/phred/33"
                            ]
                        },
                        {
                            "type": "record",
                            "name": "#trimmomatic-illumina_clipping.yaml/illuminaClipping",
                            "fields": [
                                {
                                    "name": "#trimmomatic-illumina_clipping.yaml/illuminaClipping/adapters",
                                    "type": "File",
                                    "doc": "FASTA file containing adapters, PCR sequences, etc. It is used to search\nfor and remove these sequences in the input FASTQ file(s)\n"
                                },
                                {
                                    "name": "#trimmomatic-illumina_clipping.yaml/illuminaClipping/seedMismatches",
                                    "type": "int",
                                    "doc": "specifies the maximum mismatch count which will still allow a full match\nto be performed\n"
                                },
                                {
                                    "name": "#trimmomatic-illumina_clipping.yaml/illuminaClipping/palindromeClipThreshold",
                                    "type": "int",
                                    "doc": "specifies how accurate the match between the two 'adapter ligated' reads\nmust be for PE palindrome read alignment.\n"
                                },
                                {
                                    "name": "#trimmomatic-illumina_clipping.yaml/illuminaClipping/simpleClipThreshold",
                                    "type": "int",
                                    "doc": "specifies how accurate the match between any adapter etc. sequence must\nbe against a read\n"
                                },
                                {
                                    "name": "#trimmomatic-illumina_clipping.yaml/illuminaClipping/minAdapterLength",
                                    "type": [
                                        "null",
                                        "int"
                                    ],
                                    "doc": "In addition to the alignment score, palindrome mode can verify that a\nminimum length of adapter has been detected. If unspecified, this\ndefaults to 8 bases, for historical reasons. However, since palindrome\nmode has a very low false positive rate, this can be safely reduced, even\ndown to 1, to allow shorter adapter fragments to be removed.\n"
                                },
                                {
                                    "name": "#trimmomatic-illumina_clipping.yaml/illuminaClipping/keepBothReads",
                                    "type": "boolean",
                                    "doc": "After read-though has been detected by palindrome mode, and the adapter\nsequence removed, the reverse read contains the same sequence information\nas the forward read, albeit in reverse complement. For this reason, the\ndefault behaviour is to entirely drop the reverse read. By specifying\n\"true\" for this parameter, the reverse read will also be retained, which\nmay be useful e.g. if the downstream tools cannot handle a combination of\npaired and unpaired reads.  \n"
                                }
                            ]
                        },
                        {
                            "type": "record",
                            "name": "#trimmomatic-max_info.yaml/maxinfo",
                            "fields": [
                                {
                                    "name": "#trimmomatic-max_info.yaml/maxinfo/targetLength",
                                    "type": "int"
                                },
                                {
                                    "name": "#trimmomatic-max_info.yaml/maxinfo/strictness",
                                    "type": "int"
                                }
                            ]
                        }
                    ],
                    "class": "SchemaDefRequirement"
                },
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 101,
                        "prefix": "AVGQUAL:",
                        "separate": false
                    },
                    "doc": "Drop the read if the average quality is below the specified level\n",
                    "id": "#trimmomatic.cwl/avgqual"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 13,
                        "prefix": "CROP:",
                        "separate": false
                    },
                    "doc": "Removes bases regardless of quality from the end of the read, so that the\nread has maximally the specified length after this step has been\nperformed. Steps performed after CROP might of course further shorten the\nread. The value is the number of bases to keep, from the start of the read.\n",
                    "id": "#trimmomatic.cwl/crop"
                },
                {
                    "type": "#trimmomatic-end_mode.yaml/end_mode",
                    "inputBinding": {
                        "position": 3
                    },
                    "doc": "Single End (SE) or Paired End (PE) mode\n",
                    "id": "#trimmomatic.cwl/end_mode"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 13,
                        "prefix": "HEADCROP:",
                        "separate": false
                    },
                    "doc": "Removes the specified number of bases, regardless of quality, from the\nbeginning of the read.\nThe numbser specified is the number of bases to keep, from the start of\nthe read.\n",
                    "id": "#trimmomatic.cwl/headcrop"
                },
                {
                    "type": [
                        "null",
                        "#trimmomatic-illumina_clipping.yaml/illuminaClipping"
                    ],
                    "inputBinding": {
                        "valueFrom": "${ if ( self ) {\n     return \"ILLUMINACLIP:\" + inputs.illuminaClip.adapters.path + \":\"\n       + self.seedMismatches + \":\" + self.palindromeClipThreshold + \":\"\n       + self.simpleClipThreshold + \":\" + self.minAdapterLength + \":\"\n       + self.keepBothReads;\n   } else {\n     return self;\n   }\n }\n",
                        "position": 11
                    },
                    "doc": "Cut adapter and other illumina-specific sequences from the read.",
                    "id": "#trimmomatic.cwl/illuminaClip"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "shellQuote": false
                    },
                    "doc": "JVM arguments should be a quoted, space separated list\n(e.g. \"-Xms128m -Xmx512m\")\n",
                    "id": "#trimmomatic.cwl/java_opts"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 14,
                        "prefix": "LEADING:",
                        "separate": false
                    },
                    "doc": "Remove low quality bases from the beginning. As long as a base has a\nvalue below this threshold the base is removed and the next base will be\ninvestigated.\n",
                    "id": "#trimmomatic.cwl/leading"
                },
                {
                    "type": [
                        "null",
                        "#trimmomatic-max_info.yaml/maxinfo"
                    ],
                    "inputBinding": {
                        "position": 15,
                        "valueFrom": "${ if ( self ) {\n     return \"MAXINFO:\" + self.targetLength + \":\" + self.strictness;\n   } else {\n     return self;\n   }\n }\n"
                    },
                    "doc": "Performs an adaptive quality trim, balancing the benefits of retaining\nlonger reads against the costs of retaining bases with errors.\n<targetLength>: This specifies the read length which is likely to allow\nthe location of the read within the target sequence to be determined.\n<strictness>: This value, which should be set between 0 and 1, specifies\nthe balance between preserving as much read length as possible vs.\nremoval of incorrect bases. A low value of this parameter (<0.2) favours\nlonger reads, while a high value (>0.8) favours read correctness.\n",
                    "id": "#trimmomatic.cwl/maxinfo"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 100,
                        "prefix": "MINLEN:",
                        "separate": false
                    },
                    "doc": "This module removes reads that fall below the specified minimal length.\nIf required, it should normally be after all other processing steps.\nReads removed by this step will be counted and included in the \"dropped\nreads\" count presented in the trimmomatic summary.\n",
                    "id": "#trimmomatic.cwl/minlen"
                },
                {
                    "type": [
                        "null",
                        "#trimmomatic-phred.yaml/phred"
                    ],
                    "inputBinding": {
                        "prefix": "-phred",
                        "separate": false,
                        "position": 4
                    },
                    "doc": "\"33\" or \"64\" specifies the base quality encoding. Default: 64\n",
                    "id": "#trimmomatic.cwl/phred"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1930",
                    "inputBinding": {
                        "position": 5
                    },
                    "doc": "FASTQ file of reads (R1 reads in Paired End mode)",
                    "id": "#trimmomatic.cwl/reads1"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "format": "http://edamontology.org/format_1930",
                    "inputBinding": {
                        "position": 6
                    },
                    "doc": "FASTQ file of R2 reads in Paired End mode",
                    "id": "#trimmomatic.cwl/reads2"
                },
                {
                    "type": [
                        "null",
                        "#trimmomatic-sliding_window.yaml/slidingWindow"
                    ],
                    "inputBinding": {
                        "position": 15,
                        "valueFrom": "${ if ( self ) {\n     return \"SLIDINGWINDOW:\" + self.windowSize + \":\"\n       + self.requiredQuality;\n   } else {\n     return self;\n   }\n }\n"
                    },
                    "doc": "Perform a sliding window trimming, cutting once the average quality\nwithin the window falls below a threshold. By considering multiple\nbases, a single poor quality base will not cause the removal of high\nquality data later in the read.\n<windowSize> specifies the number of bases to average across\n<requiredQuality> specifies the average quality required\n",
                    "id": "#trimmomatic.cwl/slidingwindow"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 12,
                        "prefix": "TOPHRED33",
                        "separate": false
                    },
                    "doc": "This (re)encodes the quality part of the FASTQ file to base 33.",
                    "id": "#trimmomatic.cwl/tophred33"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 12,
                        "prefix": "TOPHRED64",
                        "separate": false
                    },
                    "doc": "This (re)encodes the quality part of the FASTQ file to base 64.",
                    "id": "#trimmomatic.cwl/tophred64"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 14,
                        "prefix": "TRAILING:",
                        "separate": false
                    },
                    "doc": "Remove low quality bases from the end. As long as a base has a value\nbelow this threshold the base is removed and the next base (which as\ntrimmomatic is starting from the 3' prime end would be base preceding\nthe just removed base) will be investigated. This approach can be used\nremoving the special Illumina \"low quality segment\" regions (which are\nmarked with quality score of 2), but we recommend Sliding Window or\nMaxInfo instead\n",
                    "id": "#trimmomatic.cwl/trailing"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "trim.log"
                    },
                    "label": "Trimmomatic log",
                    "doc": "log of all read trimmings, indicating the following details:\n  the read name\n  the surviving sequence length\n  the location of the first surviving base, aka. the amount trimmed from the start\n  the location of the last surviving base in the original read\n  the amount trimmed from the end\n",
                    "id": "#trimmomatic.cwl/output_log"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1930",
                    "outputBinding": {
                        "glob": "$(inputs.reads1.nameroot).trimmed.fastq"
                    },
                    "id": "#trimmomatic.cwl/reads1_trimmed"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "format": "http://edamontology.org/format_1930",
                    "outputBinding": {
                        "glob": "$(inputs.reads1.nameroot).unpaired.trimmed.fastq"
                    },
                    "id": "#trimmomatic.cwl/reads1_trimmed_unpaired"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "format": "http://edamontology.org/format_1930",
                    "outputBinding": {
                        "glob": "${ if (inputs.reads2 ) {\n     return inputs.reads2.nameroot + '.trimmed.fastq';\n   } else {\n     return null;\n   }\n }\n"
                    },
                    "id": "#trimmomatic.cwl/reads2_trimmed_paired"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "format": "http://edamontology.org/format_1930",
                    "outputBinding": {
                        "glob": "${ if (inputs.reads2 ) {\n     return inputs.reads2.nameroot + '.unpaired.trimmed.fastq';\n   } else {\n     return null;\n   }\n }\n"
                    },
                    "id": "#trimmomatic.cwl/reads2_trimmed_unpaired"
                }
            ],
            "baseCommand": [
                "java",
                "org.usadellab.trimmomatic.Trimmomatic"
            ],
            "arguments": [
                {
                    "valueFrom": "trim.log",
                    "prefix": "-trimlog",
                    "position": 4
                },
                {
                    "valueFrom": "$(runtime.cores)",
                    "position": 4,
                    "prefix": "-threads"
                },
                {
                    "valueFrom": "$(inputs.reads1.nameroot).trimmed.fastq",
                    "position": 7
                },
                {
                    "valueFrom": "${\n  if (inputs.end_mode == \"PE\" && inputs.reads2) {\n    return inputs.reads1.nameroot + '.trimmed.unpaired.fastq';\n  } else {\n    return null;\n  }\n}\n",
                    "position": 8
                },
                {
                    "valueFrom": "${\n  if (inputs.end_mode == \"PE\" && inputs.reads2) {\n    return inputs.reads2.nameroot + '.trimmed.fastq';\n  } else {\n    return null;\n  }\n}\n",
                    "position": 9
                },
                {
                    "valueFrom": "${\n  if (inputs.end_mode == \"PE\" && inputs.reads2) {\n    return inputs.reads2.nameroot + '.trimmed.unpaired.fastq';\n  } else {\n    return null;\n  }\n}\n",
                    "position": 10
                }
            ],
            "doc": "Trimmomatic is a fast, multithreaded command line tool that can be used to trim and crop\nIllumina (FASTQ) data as well as to remove adapters. These adapters can pose a real problem\ndepending on the library preparation and downstream application.\nThere are two major modes of the program: Paired end mode and Single end mode. The\npaired end mode will maintain correspondence of read pairs and also use the additional\ninformation contained in paired reads to better find adapter or PCR primer fragments\nintroduced by the library preparation process.\nTrimmomatic works with FASTQ files (using phred + 33 or phred + 64 quality scores,\ndepending on the Illumina pipeline used).\n",
            "id": "#trimmomatic.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "Workflow",
            "label": "EMG QC workflow, (paired end version). Benchmarking with MG-RAST expt.",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "SchemaDefRequirement",
                    "types": [
                        {
                            "type": "record",
                            "name": "#FragGeneScan-model.yaml/model",
                            "fields": [
                                {
                                    "name": "#FragGeneScan-model.yaml/model/main",
                                    "type": "File"
                                },
                                {
                                    "name": "#FragGeneScan-model.yaml/model/prob_forward",
                                    "type": "File",
                                    "label": "Forward probability model"
                                },
                                {
                                    "name": "#FragGeneScan-model.yaml/model/prob_backward",
                                    "type": "File",
                                    "label": "Backward probability model"
                                },
                                {
                                    "name": "#FragGeneScan-model.yaml/model/prob_noncoding",
                                    "type": "File",
                                    "label": "Noncoding probability model"
                                },
                                {
                                    "name": "#FragGeneScan-model.yaml/model/prob_start",
                                    "type": "File",
                                    "label": "Start probability model"
                                },
                                {
                                    "name": "#FragGeneScan-model.yaml/model/prob_stop",
                                    "type": "File",
                                    "label": "Stop probability model"
                                },
                                {
                                    "name": "#FragGeneScan-model.yaml/model/prob_start1",
                                    "type": "File",
                                    "label": "Start1 probability model"
                                },
                                {
                                    "name": "#FragGeneScan-model.yaml/model/prob_stop1",
                                    "type": "File",
                                    "label": "Stop1 probability model"
                                },
                                {
                                    "name": "#FragGeneScan-model.yaml/model/pwm_dist",
                                    "type": "File",
                                    "label": "pwm distribution"
                                }
                            ]
                        },
                        {
                            "$import": "#trimmomatic-sliding_window.yaml/slidingWindow"
                        },
                        {
                            "$import": "#trimmomatic-end_mode.yaml/end_mode"
                        },
                        {
                            "$import": "#trimmomatic-phred.yaml/phred"
                        }
                    ]
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1930",
                    "id": "#main/forward_reads"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1930",
                    "id": "#main/reverse_reads"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/clean_fasta_headers/sequences_with_cleaned_headers",
                    "id": "#main/processed_sequences"
                }
            ],
            "steps": [
                {
                    "run": "#clean_fasta_headers.cwl",
                    "in": [
                        {
                            "source": "#main/convert_trimmed-reads_to_fasta/fasta",
                            "id": "#main/clean_fasta_headers/sequences"
                        }
                    ],
                    "out": [
                        "#main/clean_fasta_headers/sequences_with_cleaned_headers"
                    ],
                    "id": "#main/clean_fasta_headers"
                },
                {
                    "run": "#seqprep-merge.cwl",
                    "in": [
                        {
                            "source": "#main/overlap_reads/forward_unmerged_reads",
                            "id": "#main/combine_overlaped_and_unmerged_reads/forward_unmerged_reads"
                        },
                        {
                            "source": "#main/overlap_reads/merged_reads",
                            "id": "#main/combine_overlaped_and_unmerged_reads/merged_reads"
                        },
                        {
                            "source": "#main/overlap_reads/reverse_unmerged_reads",
                            "id": "#main/combine_overlaped_and_unmerged_reads/reverse_unmerged_reads"
                        }
                    ],
                    "out": [
                        "#main/combine_overlaped_and_unmerged_reads/merged_with_unmerged_reads"
                    ],
                    "id": "#main/combine_overlaped_and_unmerged_reads"
                },
                {
                    "run": "#fastq_to_fasta.cwl",
                    "in": [
                        {
                            "source": "#main/trim_quality_control/reads1_trimmed",
                            "id": "#main/convert_trimmed-reads_to_fasta/fastq"
                        }
                    ],
                    "out": [
                        "#main/convert_trimmed-reads_to_fasta/fasta"
                    ],
                    "id": "#main/convert_trimmed-reads_to_fasta"
                },
                {
                    "label": "Paired-end overlapping reads are merged",
                    "run": "#seqprep.cwl",
                    "in": [
                        {
                            "source": "#main/forward_reads",
                            "id": "#main/overlap_reads/forward_reads"
                        },
                        {
                            "source": "#main/reverse_reads",
                            "id": "#main/overlap_reads/reverse_reads"
                        }
                    ],
                    "out": [
                        "#main/overlap_reads/merged_reads",
                        "#main/overlap_reads/forward_unmerged_reads",
                        "#main/overlap_reads/reverse_unmerged_reads"
                    ],
                    "id": "#main/overlap_reads"
                },
                {
                    "doc": "Low quality trimming (low quality ends and sequences with < quality scores\nless than 15 over a 4 nucleotide wide window are removed)\n",
                    "run": "#trimmomatic.cwl",
                    "in": [
                        {
                            "default": "SE",
                            "id": "#main/trim_quality_control/end_mode"
                        },
                        {
                            "default": 3,
                            "id": "#main/trim_quality_control/leading"
                        },
                        {
                            "default": 100,
                            "id": "#main/trim_quality_control/minlen"
                        },
                        {
                            "default": "33",
                            "id": "#main/trim_quality_control/phred"
                        },
                        {
                            "source": "#main/combine_overlaped_and_unmerged_reads/merged_with_unmerged_reads",
                            "id": "#main/trim_quality_control/reads1"
                        },
                        {
                            "default": {
                                "windowSize": 4,
                                "requiredQuality": 15
                            },
                            "id": "#main/trim_quality_control/slidingwindow"
                        },
                        {
                            "default": 3,
                            "id": "#main/trim_quality_control/trailing"
                        }
                    ],
                    "out": [
                        "#main/trim_quality_control/reads1_trimmed"
                    ],
                    "id": "#main/trim_quality_control"
                }
            ],
            "id": "#main",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        }
    ],
    "cwlVersion": "v1.0",
    "$schemas": [
        "https://schema.org/docs/schema_org_rdfa.html",
        "http://edamontology.org/EDAM_1.16.owl"
    ],
    "$namespaces": {
        "edam": "http://edamontology.org/",
        "s": "http://schema.org/"
    }
}
